#!/usr/bin/perl -w
                                                                                                                                                                                                     
use strict;
                                                                                                                                                                                                     
my %rpmstodo = ('coreutils'     => 	'coreutils-4.5.3-26.i386.rpm',
                'vixie-cron'    => 	'vixie-cron-3.0.1-74.i386.rpm',
                'amanda'        => 	'amanda-2.4.4p1-0.3E.i386.rpm',
                'amanda-client'  => 	'amanda-client-2.4.4p1-0.3E.i386.rpm',
                'amanda-server'  =>	'amanda-server-2.4.4p1-0.3E.i386.rpm',
                'cups'          =>      'cups-1.1.17-13.3.6.i386.rpm',
                'cups-devel'    =>      'cups-devel-1.1.17-13.3.6.i386.rpm',
                'cups-libs'     =>      'cups-libs-1.1.17-13.3.6.i386.rpm',
                'inn'           =>      'inn-2.3.5-5.i386.rpm',
                'sendmail'      =>      'sendmail-8.12.10-1.i386.rpm',
                'sendmail-cf'   =>      'sendmail-cf-8.12.10-1.i386.rpm',
                'utempter'      =>      'utempter-0.5.2-16.i386.rpm',
                'uucp'          =>      'uucp-1.06.1-47.i386.rpm',
                'vte'           =>      'vte-0.11.10-3.i386.rpm',
                'vte-devel'     =>      'vte-devel-0.11.10-3.i386.rpm',
                'httpd'         =>	'httpd-2.0.46-26.ent.centos.1.i386.rpm',
                'httpd-devel'   =>	'httpd-devel-2.0.46-26.ent.centos.1.i386.rpm',
                'netdump'       =>      'netdump-0.6.11-3.i386.rpm',
                'netdump-server'  =>	'netdump-server-0.6.11-3.i386.rpm',
                'nfs-utils'     =>      'nfs-utils-1.0.6-7.EL.i386.rpm',
                'rpm'           =>      'rpm-4.2.1-4.4.i386.rpm',
                'rpm-build'     =>      'rpm-build-4.2.1-4.4.i386.rpm',
                'rpm-devel'     =>      'rpm-devel-4.2.1-4.4.i386.rpm',
                'rpm-python'    =>      'rpm-python-4.2.1-4.4.i386.rpm',
                'slocate'       =>      'slocate-2.7-3.i386.rpm'   );
                                                                                                                                                                                                     
while (my($rpm,$rpmname) = each(%rpmstodo)) {
        my $rpmstat = `rpm -q $rpm`;
                                                                                                                                                                                                     
        if($rpmstat !~ /not installed/)
                {
                print "$rpmname\n";
                `rpm -Uhv --force http://mirror.centos.org/centos/3.1/i386/RedHat/RPMS/$rpmname`;
		}
        }
